package edu.nyu.scps.progress;

import android.app.Activity;
import android.app.ProgressDialog;
import android.graphics.Color;
import android.os.AsyncTask;
import android.util.Log;
import android.widget.LinearLayout;

public class ProgressTask extends AsyncTask<Void, Integer, Void> {
	static final int max = 100;
	final Activity activity;
	final LinearLayout linearLayout;
	final int dialogId;
	final ProgressDialog progressDialog;

	//This method is executed by the main thread.
	ProgressTask(Activity activity, LinearLayout linearLayout,
		int dialogId, ProgressDialog progressDialog) {

		this.activity = activity;
		this.linearLayout = linearLayout;
		this.dialogId = dialogId;
		this.progressDialog = progressDialog;
	}

	//This method is executed by the second thread.
	//Its argument is the argument passed to the execute method.
	//Its return value is passed to onPostExecute.
	@Override
	protected Void doInBackground(Void... v) {

		for (int i = 0; i <= max && !isCancelled(); ++i) {
			try {
				Thread.sleep(100);	//milliseconds
			} catch (InterruptedException interruptedException) {
				Log.e("ERROR", "sleep interrupted", interruptedException);
			}

			//Cause onProgressUpdate to be executed by the main thread.
			publishProgress(i);
		}

		return null;
	}

	//This method is executed by the main thread.
	//Its argument is the argument passed to publishProgress.
	@Override
	protected void onProgressUpdate(Integer... progress) {
		final int gray = Math.min(progress[0], max) * 255 / max;
		linearLayout.setBackgroundColor(Color.rgb(gray, gray, gray));
		progressDialog.setProgress(progress[0]);
	}

	//This method is executed by the main thread.
	//Its argument is the value returned by doInBackground.
	@Override
	protected void onPostExecute(Void v) {
		activity.dismissDialog(dialogId);
	}
}
